[ARVADOS] updated: 7867d71a492deecfc079025481b122ce9fb37581
Git user
git at public.curoverse.com
Thu Dec 15 07:35:34 EST 2016
Summary of changes:
apps/workbench/test/diagnostics/container_request_test.rb | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
via 7867d71a492deecfc079025481b122ce9fb37581 (commit)
from 54a93a3d686fc0774c800a95a19ef063a488cffb (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
commit 7867d71a492deecfc079025481b122ce9fb37581
Author: radhika <radhika at curoverse.com>
Date: Tue Dec 13 02:35:26 2016 -0500
10241: update assertion
diff --git a/apps/workbench/test/diagnostics/container_request_test.rb b/apps/workbench/test/diagnostics/container_request_test.rb
index fca0cef..257159a 100644
--- a/apps/workbench/test/diagnostics/container_request_test.rb
+++ b/apps/workbench/test/diagnostics/container_request_test.rb
@@ -39,8 +39,8 @@ class ContainerRequestTest < DiagnosticsTest
page.assert_no_selector('a.disabled,button.disabled', text: 'Run')
find('a,button', text: 'Run').click
- # container_request is running. We have a "Pause" button instead now.
- page.assert_selector 'a,button', text: 'Pause'
+ # container_request is running. Run button is no longer available.
+ page.assert_no_selector('a', text: 'Run')
# Wait for container_request run to complete
wait_until_page_has 'completed', cr_config['max_wait_seconds']
-----------------------------------------------------------------------
hooks/post-receive
--
More information about the arvados-commits
mailing list